<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DomPlugin</name>
    <message>
        <location filename="../domplugin.cpp" line="41"/>
        <source>Panel DOM Tree</source>
        <translation>Drzewo DOM panelu</translation>
    </message>
</context>
<context>
    <name>TreeWindow</name>
    <message>
        <location filename="../treewindow.ui" line="14"/>
        <source>Panel DOM Tree</source>
        <translation>Drzewo DOM panelu</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="63"/>
        <location filename="../treewindow.ui" line="96"/>
        <source>Property</source>
        <translation>Właściwość</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="68"/>
        <source>Value</source>
        <translation>Wartość</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="76"/>
        <source>All properties</source>
        <translation>Wszystkie właściwości</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="101"/>
        <source>Type</source>
        <translation>Rodzaj</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="106"/>
        <source>String value</source>
        <translation>Ciąg znaków</translation>
    </message>
</context>
</TS>
